@@ -12,11 +12,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from newrelic_telemetry_sdk.client import SpanClient, MetricClient, HTTPError
+from newrelic_telemetry_sdk.client import (
+    SpanClient,
+    MetricClient,
+    EventClient,
+    HTTPError,
+)
 from newrelic_telemetry_sdk.span import Span
 from newrelic_telemetry_sdk.metric import GaugeMetric, CountMetric, SummaryMetric
+from newrelic_telemetry_sdk.event import Event
 from newrelic_telemetry_sdk.metric_batch import MetricBatch
-from newrelic_telemetry_sdk.span_batch import SpanBatch
+from newrelic_telemetry_sdk.batch import SpanBatch, EventBatch
 from newrelic_telemetry_sdk.harvester import Harvester
 
 try:
@@ -28,11 +34,14 @@ __all__ = (
     "HTTPError",
     "SpanClient",
     "MetricClient",
+    "EventClient",
     "Span",
     "GaugeMetric",
     "CountMetric",
     "SummaryMetric",
+    "Event",
     "MetricBatch",
     "SpanBatch",
+    "EventBatch",
     "Harvester",
 )
